MinIO wrapper code to access S3 buckets. These functions mainly delegate to the appropriate Minio classes using the async client.
MinIO wrapper code to access S3 buckets. These functions mainly delegate to the appropriate Minio classes using the async client.
(compose-object client bucket path parts & [{:keys [metadata]}])Composes new object by combining the data of multiple sources, using server-side copy.
The sources can either be a list of paths, from the same bucket, or maps with :bucket
and :object values. Optional metadata can be specified.
Note that, depending on the backend implementation, additional limitations may be imposed, such as a minimal source object size.
Composes new object by combining the data of multiple sources, using server-side copy. The sources can either be a list of paths, from the same bucket, or maps with `:bucket` and `:object` values. Optional metadata can be specified. Note that, depending on the backend implementation, additional limitations may be imposed, such as a minimal source object size.
(get-object client bucket path)Returns a future of an InputStream of the given object. Don't forget to close it
after use.
Returns a future of an `InputStream` of the given object. Don't forget to close it after use.
(list-objects client bucket prefix)Recursively lists objects in the bucket with given prefix
Recursively lists objects in the bucket with given prefix
(put-object client bucket path {:keys [stream size content-type metadata file]})Uploads stream to the specified destination. Optional content type and
metadata can be specified. Specify size if the stream size is known.
You can also specify a file instead of a stream.
Uploads stream to the specified destination. Optional content type and metadata can be specified. Specify `size` if the stream size is known. You can also specify a `file` instead of a `stream`.
(remove-object client bucket path & [version])Deletes object at given location. Returns a list of delete errors, if any.
Deletes object at given location. Returns a list of delete errors, if any.
(remove-objects client bucket paths)Deletes multiple objects, similar to remove-object.
Deletes multiple objects, similar to `remove-object`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |